@@ -1,3 +1,7 @@
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
+
 import logging
 from django.apps import AppConfig
 from django.utils.translation import gettext_lazy as _
