@@ -1,3 +1,6 @@
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
 
 import json
 import logging
@@ -13,6 +16,7 @@ from django.db.models.signals import m2m_changed
 from django.dispatch import receiver
 
 from django_middleware_global_request.middleware import get_request
+from django_middleware_request_id import get_request_id
 
 from fastutils import dictutils
 from magic_import import import_from_string
@@ -63,7 +67,12 @@ class DataHistoryBase(models.Model):
     # default_get_user_information
 
     def __str__(self):
-        return f"{self.app_label}.{self.model_name}.{self.item_id}.{self.version}"
+        return "{app_label}.{model_name}.{item_id}.{version}".format(
+            app_label=self.app_label,
+            model_name=self.model_name,
+            item_id=self.item_id,
+            version=self.version,
+        )
 
     @classmethod
     def get_user_information(cls, user):
@@ -96,7 +105,10 @@ class DataHistoryBase(models.Model):
     def userinfo_text(self):
         lines = []
         for field, value in self.get_userinfo().items():
-            line = f"{field}: {value}"
+            line = "{field}: {value}".format(
+                field=field,
+                value=value,
+            )
             lines.append(line)
         return "\n".join(lines)
 
@@ -140,7 +152,7 @@ class DataHistoryBase(models.Model):
     def add_data_history(cls, item, action, username=None, userinfo=None, save=True, ignore_unchanged_version=True):
         nowtime = timezone.now()
         request = get_request()
-        request_id = getattr(request, "request_id", None)
+        request_id = get_request_id()
 
         app_label = item._meta.app_label
         model_name = item._meta.model_name
@@ -232,15 +244,25 @@ def save_data_histories_for(Model):
 
     app_label = Model._meta.app_label
     model_name = Model._meta.model_name
-    post_save_func_name = f"save_data_histories_for_{app_label}_{model_name}_on_post_save"
-    post_delete_func_name = f"save_data_histories_for_{app_label}_{model_name}_on_post_delete"
-    
-    msg = f"adding save_data_histories_flag for model: {app_label}.{model_name}"
+    post_save_func_name = "save_data_histories_for_{app_label}_{model_name}_on_post_save".format(
+        app_label=app_label,
+        model_name=model_name,
+    )
+    post_delete_func_name = "save_data_histories_for_{app_label}_{model_name}_on_post_delete".format(
+        app_label=app_label,
+        model_name=model_name,
+    )
+    msg = "adding save_data_histories_flag for model: {app_label}.{model_name}".format(
+        app_label=app_label,
+        model_name=model_name,
+    )
     logger.debug(msg)
     setattr(Model, SAVE_DATA_HISTORIES_FLAG, True)
 
     if not hasattr(Model, post_save_func_name):
-        msg = f"registering signal handler: {post_save_func_name}..."
+        msg = "registering signal handler: {post_save_func_name}...".format(
+            post_save_func_name=post_save_func_name,
+        )
         logger.debug(msg)
         @receiver(post_save, sender=Model)
         def model_post_save(sender, instance, **kwargs):
@@ -253,7 +275,9 @@ def save_data_histories_for(Model):
         setattr(Model, post_save_func_name, model_post_save)
 
     if not hasattr(Model, post_delete_func_name):
-        msg = f"registering signal handler: {post_delete_func_name}..."
+        msg = "registering signal handler: {post_delete_func_name}...".format(
+            post_delete_func_name=post_delete_func_name,
+        )
         logger.debug(msg)
         @receiver(post_delete, sender=Model)
         def model_post_delete(sender, instance, **kwargs):
@@ -263,10 +287,16 @@ def save_data_histories_for(Model):
     
     for field in Model._meta.many_to_many:
         field_name = field.name
-        m2m_changed_func_name = f"save_data_histories_for_{app_label}_{model_name}_{field_name}_on_m2m_changed"
+        m2m_changed_func_name = "save_data_histories_for_{app_label}_{model_name}_{field_name}_on_m2m_changed".format(
+            app_label=app_label,
+            model_name=model_name,
+            field_name=field_name,
+        )
 
         if not hasattr(Model, m2m_changed_func_name):
-            msg = f"registering signal handler: {m2m_changed_func_name}..."
+            msg = "registering signal handler: {m2m_changed_func_name}...".format(
+                m2m_changed_func_name=m2m_changed_func_name,
+            )
             logger.debug(msg)
             @receiver(m2m_changed, sender=getattr(getattr(Model, field.name), "through"))
             def model_m2m_changed(sender, instance, **kwargs):
@@ -274,7 +304,6 @@ def save_data_histories_for(Model):
                 save_data_histories_for_fk_instance(instance)
             setattr(Model, m2m_changed_func_name, model_m2m_changed)
 
-
 def add_save_data_histories_flag_for_all_models():
     msg = "adding save_data_histories_flag for all models..."
     logger.debug(msg)
