@@ -1,3 +1,7 @@
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
+
 import json
 from django.core.serializers import serialize
 
@@ -25,6 +29,10 @@ def get_item_data(item):
     data["id"] = info[0]["pk"]
 
     for name in item.__class__._meta.fields_map.keys():
+        if "+" in name:
+            continue
+        if not hasattr(item, name):
+            continue
         text = serialize("json", getattr(item, name).all(), use_natural_foreign_keys=True)
         infos = json.loads(text)
         data2 = []
